timeseria package
=================

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   timeseria.models

Submodules
----------

timeseria.datastructures module
-------------------------------

.. automodule:: timeseria.datastructures
   :members:
   :inherited-members:
   :undoc-members:
   :show-inheritance:

timeseria.exceptions module
---------------------------

.. automodule:: timeseria.exceptions
   :members:
   :inherited-members:
   :undoc-members:
   :show-inheritance:

timeseria.operations module
---------------------------

.. automodule:: timeseria.operations
   :members:
   :inherited-members:
   :undoc-members:
   :show-inheritance:

timeseria.plots module
----------------------

.. automodule:: timeseria.plots
   :members:
   :inherited-members:
   :undoc-members:
   :show-inheritance:

timeseria.storages module
-------------------------

.. automodule:: timeseria.storages
   :members:
   :inherited-members:
   :undoc-members:
   :show-inheritance:

timeseria.time module
---------------------

.. automodule:: timeseria.time
   :members:
   :inherited-members:
   :undoc-members:
   :show-inheritance:

timeseria.transformations module
--------------------------------

.. automodule:: timeseria.transformations
   :members:
   :inherited-members:
   :undoc-members:
   :show-inheritance:

timeseria.units module
----------------------

.. automodule:: timeseria.units
   :members:
   :inherited-members:
   :undoc-members:
   :show-inheritance:

timeseria.utilities module
--------------------------

.. automodule:: timeseria.utilities
   :members:
   :inherited-members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: timeseria
   :members:
   :inherited-members:
   :undoc-members:
   :show-inheritance:
